![pypi](https://img.shields.io/pypi/v/umlcharter.svg)
![versions](https://img.shields.io/pypi/pyversions/umlcharter.svg)

# umlcharter
Python package for quick diagrams creation without a need to learn a new DSL.

The goal of this package is to provide a tool for convenient and quick creation of the diagrams as a code
in the popular DSLs (PlantUML, Mermaid, D2, etc) using simple python constructions.

For the examples of how this package can be used and the list of exactly supported DSLs, 
please check the documentation:
- [Sequence Diagrams](https://github.com/mikalaiyurkin/umlcharter/blob/master/docs/sequence_diagram/README.md)
